package com.caimei365.manager.service.caimei.svip;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmUser;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.svip.*;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/7
 */
public interface CmSvipHistoryService {

    /**
     * 超级会员列表
     * @param vip
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmSvipHistory>> memberList(CmSvipHistory vip, Integer pageNum, Integer pageSize);

    /**
     * 获取机构信息
     * @param clubId
     * @param name
     * @param shortName
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmUser>> findClubList(Integer clubId, String name, String shortName, Integer pageNum, Integer pageSize);

    /**
     * 赠送超级会员
     * @param cmSvipGive
     * @return
     */
    ResponseJson saveGive(CmSvipGive cmSvipGive) throws Exception ;

    /**
     * 获取购买记录
     * @param cmSvipHistory
     * @return
     */
    ResponseJson<PaginationVo<CmSvipHistory>> findHistory(CmSvipHistory cmSvipHistory, int pageNum, int pageSize);

    /**
     * 超级会员专属优惠券
     * @param cmVipCoupon
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmVipCoupon>> couponList(CmVipCoupon cmVipCoupon, int pageNum, int pageSize);

    /**
     * 编辑超级会员优惠券
     * @param id
     * @param configure
     * @return
     */
    ResponseJson<Map<String, Object>> cmVipCouponForm(Integer id,Integer configure);

    /**
     * 保存超级会员优惠券
     * @param svipcouponForm
     * @return
     */
    ResponseJson saveVipCoupon(SvipCouponForm svipcouponForm);

    /**
     * 删除优惠券
     * @param id
     * @return
     */
    ResponseJson delCoupon(Integer id);

    /**
     * 关闭超级会员专属优惠券
     * @param id
     * @return
     */
    ResponseJson closeCoupon(Integer id);

    /**
     * 开启超级会员专属优惠券
     * @param id
     * @return
     */
    ResponseJson openCoupon(Integer id);

    /**
     * 删除超级会员专属优惠券
     * @param id
     * @return
     */
    ResponseJson deleteCoupon(Integer id);

    /**
     * 获取供应商列表
     * @param cmShop
     * @return
     */
    ResponseJson<PaginationVo<NewCmShop>> findShopList(NewCmShop cmShop, int pageNum, int pageSize);

    /**
     * 获取商品列表
     * @param product
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<Product>> findProductDialogList(Product product, int pageNum, int pageSize);

    /**
     *超级会员优惠商品
     * @param svipProduct
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmSvipProduct>> findProductList(CmSvipProduct svipProduct, Integer pageNum, Integer pageSize);

    /**
     * 排序
     * @param id
     * @param sort
     * @return
     */
    ResponseJson updateSort(Integer id ,Integer sort);

    /**
     * 编辑超级会员商品
     * @param id
     * @return
     */
    ResponseJson findSkuList(Integer id);

    /**
     * 保存超级会员商品
     * @param cmSvipProduct
     * @return
     */
    ResponseJson saveSvipProduct(CmSvipProduct cmSvipProduct);

    /**
     * 删除超级会员商品
     * @param id
     * @return
     */
    ResponseJson deleteSvipProduct(Integer id);

    /**
     * 宣传图
     * @return
     */
    ResponseJson getAdsImage();

    /**
     *  保存宣传图
     * @param adsImage
     * @return
     */
    ResponseJson saveAdsImage(CmSvipProductAdsImage adsImage);
    /**
     * 套餐配置
     * @return
     */
    ResponseJson<CmSvipPackage> findPackage();

    /**
     * 更新超级会员套餐信息
     * @param cmSvipPackage
     * @return
     */
    ResponseJson updatePrice(CmSvipPackage cmSvipPackage);

}
