package com.caimei365.manager.service.caimei.user;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmShop;
import com.caimei365.manager.entity.caimei.cmUser.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/5
 */
public interface CustomerService {
    /**
     * 潜客供应商列表
     * @param cmShopStatistics
     * @return
     */
    ResponseJson<PaginationVo<CmShopStatistics>> getCustomerShopList(CmShopStatistics cmShopStatistics, Integer pageNum, Integer pageSize);

    /**
     * 供应商列表
     * @param shopName
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmShop>> getShopLiat(String shopName, Integer pageNum, Integer pageSize);

    /**
     * 添加统计供应商
     * @return
     */
    ResponseJson saveCustomerShop(String shopIds);

    /**
     * 设置统计状态
     * @param id
     * @param status
     * @return
     */
    ResponseJson renewCustomerShop(Integer id, Integer status);

    /**
     * 游客统计
     * @param cmRoosInformation
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmRoosInformation>> getCmInformationList(CmRoosInformation cmRoosInformation, Integer pageNum, Integer pageSize);

    /**
     * 设置跟进状态
     * @param id
     * @param followUpStatus
     * @return
     */
    ResponseJson renewFollowUpStatus(Integer id, Integer followUpStatus, Integer serviceProviderId);

    /**
     * 添加游客备注
     * @param cmInformationNotes
     * @return
     */
    ResponseJson saveInformationNotes(CmInformationNotes cmInformationNotes);

    /**
     * 获取游客备注信息
     * @param informationId
     * @return
     */
    ResponseJson<PaginationVo<CmInformationNotes>> getInformationNotes(Integer informationId, int pageNum, int pageSize);

    /**
     * 相关文章列表
     * @param cmShopInfo
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmShopInfo>> getShopInfoList(CmShopInfo cmShopInfo, Integer pageNum, Integer pageSize);

    /**
     * 选择文章
     * @param id
     * @param title
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<Info>> getInfoList(Integer id, String title, Integer pageNum, Integer pageSize);

    /**
     * 添加文章统计
     * @param shopId
     * @param infoIds
     * @return
     */
    ResponseJson saveShopInfo(Integer shopId, String infoIds);

    /**
     * 设置统计状态
     * @param id
     * @param status
     * @return
     */
    ResponseJson renewShopInfo(Integer id, Integer status);

    /**
     * 删除统计文章
     * @param id
     * @return
     */
    ResponseJson delShopInfo(Integer id);

    /**
     * 相关搜索词列表
     * @param cmShopKeyword
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmShopKeyword>> getShopKeywordList(CmShopKeyword cmShopKeyword, Integer pageNum, Integer pageSize);

    /**
     * 选择关键词
     * @param keyword
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmUserSearchFrequency>> getSearchFrequencyList(String keyword, Integer pageNum, Integer pageSize);

    /**
     * 添加搜索词统计
     * @param shopId
     * @param keyWordIds
     * @return
     */
    ResponseJson saveShopKeyword(Integer shopId, String keyWordIds);

    /**
     * 设置统计状态
     * @param id
     * @param status
     * @return
     */
    ResponseJson renewShopKeyword(Integer id, Integer status);

    /**
     * 删除统计搜索词
     * @param id
     * @return
     */
    ResponseJson delShopKeyword(Integer id);

    /**
     * 弹框数据回显
     * @param shopId
     * @return
     */
    ResponseJson<CmShopPopUp> getShopPopUp(Integer shopId);

    /**
     * 谈款数据保存
     * @param cmShopPopUp
     * @return
     */
    ResponseJson saveShopPopUp(CmShopPopUp cmShopPopUp);

    /**
     * 供应商广告列表
     * @param cmShopAdvertisingImage
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PaginationVo<CmShopAdvertisingImage>> getShopAdvertisingImage(CmShopAdvertisingImage cmShopAdvertisingImage, Integer pageNum, Integer pageSize);

    /**
     * 供应商广告信息回显
     * @param id
     * @return
     */
    ResponseJson<CmShopAdvertisingImage> getShopAdvertisingImageById(Integer id);

    /**
     * 保存供应商广告信息
     * @param cmShopAdvertisingImage
     * @return
     */
    ResponseJson saveShopAdvertisingImage(CmShopAdvertisingImage cmShopAdvertisingImage);

    /**
     * 一键排序
     * @param id
     * @param sort
     * @return
     */
    ResponseJson renewShopAdvertisingImageSort(Integer id, Integer sort);

    /**
     * 修改上下架状态
     * @param id
     * @param status
     * @return
     */
    ResponseJson renewShopAdvertisingImageStatus(Integer id, Integer status);

    /**
     * 删除广告
     * @param id
     * @return
     */
    ResponseJson delShopAdvertisingImage(Integer id);

    /**
     * 供应商主页统计
     * @param shopId
     * @param startTime
     * @param endTime
     * @return
     */
    ResponseJson<PaginationVo<CmPageShop>> getPageShop(Integer shopId, String startTime, String endTime, Integer pageNum, Integer pageSize);

    /**
     * 供应商商品统计
     * @param shopId
     * @return
     */
    ResponseJson<PaginationVo<CmPageShopProduct>> getPageShopProduct(Integer shopId, String startTime, String endTime, Integer pageNum, Integer pageSize);

    /**
     * 供应商文章
     * @param shopId
     * @return
     */
    ResponseJson<PaginationVo<CmPageShopInfo>> getPageShopInfo(Integer shopId, String startTime, String endTime, Integer pageNum, Integer pageSize);

    /**
     * 供应商搜索词统计
     * @param shopId
     * @return
     */
    ResponseJson<PaginationVo<CmPageShopKeyword>> getPageShopKeyword(Integer shopId, String startTime, String endTime, Integer pageNum, Integer pageSize);

}
