package com.caimei365.manager.service.wechat.impl;

import com.caimei365.manager.dao.SystemDao;
import com.caimei365.manager.dao.WeChatDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatReply;
import com.caimei365.manager.service.wechat.WechatReplyService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@Slf4j
@Service
public class WechatReplyServiceImpl implements WechatReplyService {

    @Value("${wechat.caimei.id}")
    private String caimeiId;
    @Value("${wechat.hehe.id}")
    private String heheId;

    @Resource
    private WeChatDao weChatDao;
    @Resource
    private SystemDao systemDao;

    /**
     * 获取回复配置列表
     *
     * @param type         类型： 1采美，2呵呵商城
     * @param title        回复素材标题
     * @param responseType 事件类型
     * @param msgType      回复类型
     * @param pageNum      页码
     * @param pageSize     每页大小
     */
    @Override
    public ResponseJson<PaginationVo<WechatReply>> getReplyList(Integer type, String title, String responseType, String msgType, int pageNum, int pageSize) {
        String wxType = "";
        if (null != type && 1 == type) {
            wxType = caimeiId;
        } else if (null != type && 2 == type) {
            wxType = heheId;
        } else {
            return ResponseJson.error("配置类型不能为空", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WechatReply> replyList = weChatDao.getReplyList(wxType, title, responseType, msgType);
        PaginationVo<WechatReply> pageData = new PaginationVo<>(replyList);
        return ResponseJson.success(pageData);
    }

    /**
     * 根据ID获取回复配置
     */
    @Override
    public ResponseJson<WechatReply> getReply(Integer id) {
        WechatReply reply = weChatDao.getWechatReply(id);
        return ResponseJson.success(reply);
    }

    /**
     * 根据ID更新回复配置
     */
    @Override
    public ResponseJson<Void> updateReply(Integer id, WechatReply reply, String username) {
        WechatReply dbReply = weChatDao.getWechatReply(id);
        if (null == dbReply) {
            return ResponseJson.error("当前回复配置异常！", null);
        }
        if (StringUtils.hasLength(reply.getMsgType())) {
            dbReply.setMsgType(reply.getMsgType());
        }
        if (StringUtils.hasLength(reply.getResponseType())) {
            dbReply.setResponseType(reply.getResponseType());
        }
        if (StringUtils.hasLength(reply.getKeyword())) {
            dbReply.setKeyword(reply.getKeyword());
        }
        if (StringUtils.hasLength(reply.getTitle())) {
            dbReply.setTitle(reply.getTitle());
        }
        dbReply.setRelateId(reply.getRelateId());
        Integer userId = systemDao.getUserIdByUsername(username);
        dbReply.setUserId(userId);
        // 更新
        weChatDao.updateWechatReply(dbReply);
        return ResponseJson.success();
    }

    /**
     * 添加回复配置
     */
    @Override
    public ResponseJson<Void> addReply(WechatReply reply, String username) {
        if (null != reply.getType() && 1 == reply.getType()) {
            reply.setWxType(caimeiId);
        } else if (null != reply.getType() && 2 == reply.getType()) {
            reply.setWxType(heheId);
        } else {
            return ResponseJson.error("配置类型type不正确！", null);
        }
        Integer userId = systemDao.getUserIdByUsername(username);
        reply.setUserId(userId);
        // 新增
        weChatDao.insertWechatReply(reply);
        return ResponseJson.success();
    }

    /**
     * 根据ID删除回复配置
     */
    @Override
    public ResponseJson<Void> deleteReply(Integer id) {
        weChatDao.deleteWechatReply(id);
        return ResponseJson.success();
    }
}
